/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import java.util.Date;

import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class AcctPackPrint represents an accounting packet with print information.
 */
@Struct
public class AcctPackPrint extends AcctPack {
	@StructField(n=2,type=FieldType.INT4)
	private int printsts;
	@StructField(n=3,type=FieldType.VMSTIME)
	private Date quetime;
	@StructField(n=4,type=FieldType.VMSTIME)
	private Date begtime;
	@StructField(n=5,type=FieldType.INT4)
	private int symcputim;
	@StructField(n=6,type=FieldType.INT4)
	private int pagecnt;
	@StructField(n=7,type=FieldType.INT4)
	private int qiocnt;
	@StructField(n=8,type=FieldType.INT4)
	private int getcnt;
	/**
	 * Get print status.
	 * @return print status
	 */
	public int getPrintsts() {
		return printsts;
	}
	/**
	 * Get queuing time.
	 * @return queuing time
	 */
	public Date getQuetime() {
		return quetime;
	}
	/**
	 * Get begin time.
	 * @return begin time
	 */
	public Date getBegtime() {
		return begtime;
	}
	/**
	 * Get symbiont CPU time.
	 * @return symbiont CPU time
	 */
	public int getSymcputim() {
		return symcputim;
	}
	/**
	 * Get page count.
	 * @return page count.
	 */
	public int getPagecnt() {
		return pagecnt;
	}
	/**
	 * Get QIO count.
	 * @return QIO count
	 */
	public int getQiocnt() {
		return qiocnt;
	}
	/**
	 * Get get from file count.
	 * @return get from file count
	 */
	public int getGetcnt() {
		return getcnt;
	}
	protected String subToString() {
		return "print";
	}
}
