/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import dk.vajhoej.record.Struct;

/**
 * Class AcctPackType represents an accounting packet type.
 */
@Struct
public class AcctPackType extends AcctType {
	/**
	 * ID.
	 */
	public static final int ACR$K_ID = 1;
	/**
	 * Resource.
	 */
	public static final int ACR$K_RESOURCE = 2;
	/**
	 * Image name.
	 */
	public static final int ACR$K_IMAGENAME = 3;
	/**
	 * File name.
	 */
	public static final int ACR$K_FILENAME = 4;
	/**
	 * User data.
	 */
	public static final int ACR$K_USER_DATA = 5;
	/**
	 * Print.
	 */
	public static final int ACR$K_PRINT	= 8;
	@Override
	public String toString() {
		return "(type=" + typeToString(type) + ",version=" + versionToString(version) + ")";
	}
	protected String typeToString(int type) {
		switch(type) {
			case ACR$K_ID:
				return "Id";
			case ACR$K_RESOURCE:
				return "Resource";
			case ACR$K_IMAGENAME:
				return "Image Name";
			case ACR$K_FILENAME:
				return "File Name";
			case ACR$K_USER_DATA:
				return "User Data";
			case ACR$K_PRINT:
				return "Print";
			default:
				return "Unknown";
		}
	}
}
