/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import dk.vajhoej.record.InfoProvider;
import dk.vajhoej.record.LengthProvider2;

/**
 * Class AcctRecProvider provides lengths for various variable length items in accounting records.
 */
public class AcctRecProvider implements LengthProvider2 {
	public int getLength(Object o, int n) {
		if(n == 4) {
			if(System.getProperty("os.name").equals("OpenVMS")) {
				return 0; // VMS VAR files work funny in Java
			}
			return System.getProperty("line.separator").length();
		} else {
			return -1; // ignore
		}
	}
	public int getMaxLength() {
		return 32767; // VMS max variable length record
	}
	public int getElements(Object o, int n) {
		if (n == 3) {
			int typ = ((AcctRec)o).getType().type;
			switch (typ) {
				case AcctRecType.ACR$K_PRCDEL:
				case AcctRecType.ACR$K_SYSINIT:
				case AcctRecType.ACR$K_LOGFAIL:
				case AcctRecType.ACR$K_PRINT:
				case AcctRecType.ACR$K_USER:
					return 2;
				case AcctRecType.ACR$K_IMGDEL:
					return 3;
				case AcctRecType.ACR$K_FILE_FL:
				case AcctRecType.ACR$K_FILE_BL:
					return 1;
				default:
					throw new RuntimeException("Unknown accounting record type: " + typ);
			}
		} else {
			return -1; // ignore
		}
	}
	public InfoProvider getLengthProvider(Object o, int n) {
		if (n == 3) {
			return new AcctPackProvider(); // new provider for packs
		} else {
			return null; // ignore
		}
	}
}
