/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import dk.vajhoej.record.Struct;

/**
 * Class AcctRecType represents an accounting record type.
 */
@Struct
public class AcctRecType extends AcctType {
	/**
	 * Process terminate.
	 */
	public static final int ACR$K_PRCDEL = 1;
	/**
	 * Image terminate.
	 */
	public static final int ACR$K_IMGDEL = 3;
	/**
	 * System init.
	 */
	public static final int ACR$K_SYSINIT = 5;
	/**
	 * Login failure.
	 */
	public static final int ACR$K_LOGFAIL = 7;
	/**
	 * Print job finished.
	 */
	public static final int ACR$K_PRINT = 8;
	/**
	 * Message.
	 */
	public static final int ACR$K_USER = 9;
	/**
	 * File open.
	 */
	public static final int ACR$K_FILE_FL = 13;
	/**
	 * File close.
	 */
	public static final int ACR$K_FILE_BL = 14;
	/**
	 * Interactive.
	 */
	public static final int ACR$K_INTERACTIVE = 1;
	/**
	 * Subprocess.
	 */
	public static final int ACR$K_SUBPROCESS = 2;
	/**
	 * Detached.
	 */
	public static final int ACR$K_DETACHED = 3;
	/**
	 * Batch.
	 */
	public static final int ACR$K_BATCH = 4;
	/**
	 * Network.
	 */
	public static final int ACR$K_NETWORK = 5;
	@Override
	public String toString() {
		return "(type=" + typeToString(type) + ",subtype=" + subtypeToString(type, subtype) + ",version=" + versionToString(version) + ")";
	}
	protected String typeToString(int type) {
		switch(type) {
			case ACR$K_PRCDEL:
				return "Process Terminate";
			case ACR$K_IMGDEL:
				return "Image Terminate";
			case ACR$K_SYSINIT:
				return "System Init";
			case ACR$K_LOGFAIL:
				return "Login Failure";
			case ACR$K_PRINT:
				return "Print Job Finished";
			case ACR$K_USER:
				return "Message";
			case ACR$K_FILE_FL:
				return "File Open";
			case ACR$K_FILE_BL:
				return "File Close";
			default:
				return "Unknown";
		}
	}
	protected String subtypeToString(int type, int subtype) {
		if(type == ACR$K_PRCDEL || type == ACR$K_IMGDEL) {
			switch(subtype) {
				case ACR$K_INTERACTIVE:
					return "Interactive";
				case ACR$K_SUBPROCESS:
					return "Subprocess";
				case ACR$K_DETACHED:
					return "Detached";
				case ACR$K_BATCH:
					return "Batch";
				case ACR$K_NETWORK:
					return "Network";
				default:
					return "Unknown";
			}
		} else {
			return "";
		}
	}
}
