/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct;

import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class AcctType represents an accounting type with type and sub-type. 
 */
@Struct
public class AcctType {
	/**
	 * VMS version 2.x.
	 */
	public static final int ACR$K_VERSION2 = 0;
	/**
	 * VMS version 3.0 FT.
	 */
	public static final int ACR$K_VERSION3T = 1;
	/**
	 * VMS version 3.0 - 7.3.
	 */
	public static final int ACR$K_VERSION3 = 2;
	/**
	 * VMS version 8.4-.
	 */
	public static final int ACR$K_VERSION4 = 3;
	@StructField(n=1,type=FieldType.BIT,length=1)
	protected int packet;
	@StructField(n=0,type=FieldType.BIT,length=7)
	protected int type;
	@StructField(n=4,type=FieldType.BIT,length=4)
	protected int subtype;
	@StructField(n=3,type=FieldType.BIT,length=3)
	protected int version;
	@StructField(n=2,type=FieldType.BIT,length=1)
	protected int customer;
	protected String versionToString(int version) {
		switch(version) {
			case ACR$K_VERSION2:
				return "VMS 2.x";
			case ACR$K_VERSION3T:
				return "VMS 3.0 FT";
			case ACR$K_VERSION3:
				return "VMS 3.0 - 8.3";
			case ACR$K_VERSION4:
				return "VMS 8.4-";
			default:
				return "Unknown";
		}
	}
	/**
	 * Get type.
	 * @return type
	 */
	public int getType() {
		return type;
	}
	/**
	 * Get sub-type.
	 * @return sub-type
	 */
	public int getSubtype() {
		return subtype;
	}
	/**
	 * Get version.
	 * @return version
	 */
	public int getVersion() {
		return version;
	}
	/**
	 * Get customer indicator.
	 * @return 0 if VMS, 1 if customer software
	 */
	public int getCustomer() {
		return customer;
	}
}

