/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct.db;

import dk.vajhoej.vms.acct.AcctPack;
import dk.vajhoej.vms.acct.AcctPackID;
import dk.vajhoej.vms.acct.AcctPackImagename;
import dk.vajhoej.vms.acct.AcctPackPrint;
import dk.vajhoej.vms.acct.AcctPackResource;
import dk.vajhoej.vms.acct.AcctPackType;
import dk.vajhoej.vms.acct.AcctRec;
import dk.vajhoej.vms.acct.AcctRecType;

public class AcctDbFactory {
	private static AcctPackID findIdPack(AcctRec ar) {
		for(AcctPack ap : ar.getPacks()) {
			if(ap.getType().getType() == AcctPackType.ACR$K_ID) {
				return (AcctPackID)ap;
			}
		}
		return null;
	}
	private static AcctPackResource findResourcePack(AcctRec ar) {
		for(AcctPack ap : ar.getPacks()) {
			if(ap.getType().getType() == AcctPackType.ACR$K_RESOURCE) {
				return (AcctPackResource)ap;
			}
		}
		return null;
	}
	private static AcctPackImagename findImagePack(AcctRec ar) {
		for(AcctPack ap : ar.getPacks()) {
			if(ap.getType().getType() == AcctPackType.ACR$K_IMAGENAME) {
				return (AcctPackImagename)ap;
			}
		}
		return null;
	}
	private static AcctPackPrint findPrintPack(AcctRec ar) {
		for(AcctPack ap : ar.getPacks()) {
			if(ap.getType().getType() == AcctPackType.ACR$K_PRINT) {
				return (AcctPackPrint)ap;
			}
		}
		return null;
	}
	public static AcctDbInfo convert(AcctRec ar, AcctDbIdGen idgen) {
		AcctPackID id;
		switch(ar.getType().getType()) {
			case AcctRecType.ACR$K_PRCDEL:
				id = findIdPack(ar);
				AcctPackResource res = findResourcePack(ar);
				String proctyp;
				switch(ar.getType().getSubtype()) {
					case AcctRecType.ACR$K_INTERACTIVE:
						proctyp = "Interactive";
						break;
					case AcctRecType.ACR$K_SUBPROCESS:
						proctyp = "Subprocess";
						break;
					case AcctRecType.ACR$K_DETACHED:
						proctyp = "Detached";
						break;
					case AcctRecType.ACR$K_BATCH:
						proctyp = "Batch";
						break;
					case AcctRecType.ACR$K_NETWORK:
						proctyp = "Network";
						break;
					default:
						proctyp = "Unknown";
						break;
				}
				return new AcctDbInfoProcess(idgen.getInfoId(), ar.getSystime(), id.getUsername(), id.getPidAsString(), proctyp, res.getLogin(), res.getCputime(), res.getWspeak(), res.getBiocnt(), res.getDiocnt());
			case AcctRecType.ACR$K_IMGDEL:
				id = findIdPack(ar);
				AcctPackImagename img = findImagePack(ar);
				return new AcctDbInfoImage(idgen.getInfoId(), ar.getSystime(), id.getUsername(), id.getPidAsString(), img.getImagename());
			case AcctRecType.ACR$K_SYSINIT:
				id = findIdPack(ar);
				return new AcctDbInfo(idgen.getInfoId(), "System Init", ar.getSystime(), id.getUsername(), id.getPidAsString());
			case AcctRecType.ACR$K_PRINT:
				id = findIdPack(ar);
				AcctPackPrint prt = findPrintPack(ar);
				return new AcctDbInfoPrint(idgen.getInfoId(), ar.getSystime(), id.getUsername(), id.getPidAsString(), prt.getPagecnt());
			default:
				return null;
		}
	}
}
