/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.acct.tools;

import java.io.IOException;
import java.text.ParseException;
import java.util.logging.Level;
import java.util.logging.Logger;


import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import dk.vajhoej.record.RecordException;
import dk.vajhoej.vms.acct.AcctFile;
import dk.vajhoej.vms.acct.AcctRec;
import dk.vajhoej.vms.acct.db.AcctDbFactory;
import dk.vajhoej.vms.acct.db.AcctDbIdGen;
import dk.vajhoej.vms.acct.db.AcctDbIdGenSeq;
import dk.vajhoej.vms.acct.db.AcctDbInfo;

public class ToDb {
	public static void main(String[] args) throws IOException, RecordException, ParseException {
	    try {
            if(args.length >= 2) {
                AcctFile af = new AcctFile(args[0]);
                Logger.getLogger("org.hibernate").setLevel(Level.OFF);
                EntityManagerFactory emf = Persistence.createEntityManagerFactory(args[1]);
                EntityManager em = emf.createEntityManager();
                AcctDbIdGen idgen = new AcctDbIdGenSeq(em);
                int n1 = 0;
                while(af.more()) {
                    AcctRec ar = af.read();
                    AcctDbInfo adi = AcctDbFactory.convert(ar, idgen);
                    if(adi != null) {
                        em.getTransaction().begin();
                        em.persist(adi);
                        em.getTransaction().commit();
                        n1++;
                    }
                }
                System.out.printf("%d Account info inserted\n", n1);
                em.close();
                emf.close();
                af.close();
            } else {
                System.out.println("Usage: java -cp vmsacct.jar:... dk.vajhoej.vms.acct.tools.ToDb <account-file> <persistence-unit-name>");
            }
	    } catch(Throwable ex) {
	        ex.printStackTrace();
	    }
	}
}
